==> ideaIC-213.7172.25-sources.jar: com/intellij/ide/fileTemplates/CreateFromTemplateHandler.java <==
// Copyright 2000-2021 JetBrains s.r.o. Use of this source code is governed by the Apache 2.0 license that can be found in the LICENSE file.
package com.intellij.ide.fileTemplates;

import com.intellij.ide.IdeBundle;
import com.intellij.openapi.extensions.ExtensionPointName;
import com.intellij.openapi.project.Project;
import com.intellij.psi.PsiDirectory;
import com.intellij.psi.PsiElement;
import com.intellij.util.IncorrectOperationException;
import org.jetbrains.annotations.ApiStatus;
import org.jetbrains.annotations.Nls;
import org.jetbrains.annotations.NotNull;

import java.util.Map;


public interface CreateFromTemplateHandler {
  ExtensionPointName<CreateFromTemplateHandler> EP_NAME = ExtensionPointName.create("com.intellij.createFromTemplateHandler");

  boolean handlesTemplate(@NotNull FileTemplate template);

  @NotNull
  PsiElement createFromTemplate(@NotNull Project project,
                                @NotNull PsiDirectory directory,
                                String fileName,
                                @NotNull FileTemplate template,
                                @NotNull String templateText,
                                @NotNull Map<String, Object> props) throws IncorrectOperationException;

  boolean canCreate(PsiDirectory @NotNull [] dirs);

  boolean isNameRequired();

  @NotNull
  @Nls(capitalization = Nls.Capitalization.Title)
  String getErrorMessage();

  void prepareProperties(@NotNull Map<String, Object> props);

  /**
   * @deprecated use {@link CreateFromTemplateHandler#prepareProperties(Map, String, FileTemplate, Project)} instead
   */
  @ApiStatus.ScheduledForRemoval(inVersion = "2022.1")
  @Deprecated
  default void prepareProperties(@NotNull Map<String, Object> props, String fileName, @NotNull FileTemplate template) {}

  default void prepareProperties(@NotNull Map<String, Object> props,
                                 String fileName,
                                 @NotNull FileTemplate template,
                                 @NotNull Project project) {}

  @NotNull
  @Nls(capitalization = Nls.Capitalization.Title)
  default String commandName(@NotNull FileTemplate template) {
    return IdeBundle.message("command.create.file.from.template");
  }
}

==> ideaIC-2018.3.3-sources.jar: com/intellij/ide/fileTemplates/CreateFromTemplateHandler.java <==
/*
 * Copyright 2000-2016 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.intellij.ide.fileTemplates;

import com.intellij.ide.IdeBundle;
import com.intellij.openapi.extensions.ExtensionPointName;
import com.intellij.openapi.project.Project;
import com.intellij.psi.PsiDirectory;
import com.intellij.psi.PsiElement;
import com.intellij.util.IncorrectOperationException;
import org.jetbrains.annotations.NotNull;

import java.util.Map;

/**
 * @author yole
 */
public interface CreateFromTemplateHandler {
  ExtensionPointName<CreateFromTemplateHandler> EP_NAME = ExtensionPointName.create("com.intellij.createFromTemplateHandler");

  boolean handlesTemplate(@NotNull FileTemplate template);

  @NotNull
  PsiElement createFromTemplate(@NotNull Project project,
                                @NotNull PsiDirectory directory,
                                String fileName,
                                @NotNull FileTemplate template,
                                @NotNull String templateText,
                                @NotNull Map<String, Object> props) throws IncorrectOperationException;

  boolean canCreate(@NotNull PsiDirectory[] dirs);

  boolean isNameRequired();

  @NotNull
  String getErrorMessage();

  void prepareProperties(@NotNull Map<String, Object> props);

  @NotNull
  default String commandName(@NotNull FileTemplate template) {
    return IdeBundle.message("command.create.file.from.template");
  }
}
